@@ -75,6 +75,7 @@ corpus.lang = "English.all"
 analyzed.features = "w"
 ngram.size = 1
 preserve.case = FALSE
+encoding = "native.enc"
 
 
 #######  MATHEMATICAL SETTINGS (DISTANCE MEASURE)  #################
@@ -105,9 +106,9 @@ distance.measure = "CD"
 
 
 # Method of building a dendrogram; choose one of the following linkage methods:
-# "nj", "ward", "single", "complete", "average", "mcquitty", "median", 
-# "centroid"
-linkage = "ward"
+# "nj", "ward.D", "ward.D2", "single", "complete", "average", "mcquitty", 
+# "median", "centroid"
+linkage = "ward.D"
 
 
 
@@ -446,6 +447,26 @@ if(distance.measure %in% c("CD","AL","ED","ES","MH","CB","EU") == FALSE) {
 }
 
 
+
+# in version R 3.0.4 the method "ward" has been replaced 
+# by "ward.D" and "ward.D2"; this sanity check takes care 
+# of passing the right argument
+if(R.Version()$major <= 3 & R.Version()$minor <= 0.3) {
+  if(linkage == "ward.D") {
+    linkage = "ward"
+  }
+  if(linkage == "ward.D2") {
+    linkage = "ward"
+  }
+} else {
+  if(linkage == "ward") {
+    linkage = "ward.D"
+  }
+}
+
+
+
+
 # the final stage involves creating a list and putting all the variables on it;
 # certainly, the list should not contain itself (!), it also should not 
 # contain the index "i" used to generate the list
@@ -457,7 +478,6 @@ for(i in ls()[!ls() %in% c("i","default.variables")]) {
 
 
 
-
 # Code that enables overwriting the variables with custom settings.
 # A magnificent snipped for combining two lists 
 # http://stackoverflow.com/questions/13811501/r-merge-lists-with-overwrite-and-recursion
